# Autogenerated by nbdev

d = { 'settings': { 'allowed_cell_metadata_keys': '',
                'allowed_metadata_keys': '',
                'audience': 'Developers',
                'author': 'Clive',
                'author_email': 'clive@gm.net.nz',
                'black_formatting': 'False',
                'branch': 'main',
                'clean_ids': 'True',
                'copyright': 'Put your copyright info here',
                'custom_sidebar': 'False',
                'description': 'Create a continuous colormap in matplotlib',
                'doc_baseurl': '/continuous_cmap/',
                'doc_host': 'https://CJP123.github.io',
                'doc_path': '_docs',
                'git_url': 'https://github.com/CJP123/continuous_cmap/',
                'host': 'github',
                'jupyter_hooks': 'True',
                'keywords': 'nbdev',
                'language': 'English',
                'lib_name': 'continuous_cmap',
                'lib_path': 'continuous_cmap',
                'license': 'apache2',
                'min_python': '3.9',
                'nbs_path': '.',
                'readme_nb': 'index.ipynb',
                'recursive': 'False',
                'repo': 'continuous_cmap',
                'requirements': 'fastcore pandas matplotlib',
                'status': '2',
                'title': 'continuous_cmap',
                'tst_flags': 'notest',
                'user': 'CJP123',
                'version': '0.0.4'},
  'syms': {'continuous_cmap.cmap': {'continuous_cmap.cmap.get_continuous_cmap': 'https://CJP123.github.io/continuous_cmap/cmap.html#get_continuous_cmap'}}}